var classtvg_1_1Fill =
[
    [ "ColorStop", "structtvg_1_1Fill_1_1ColorStop.html", "structtvg_1_1Fill_1_1ColorStop" ],
    [ "colorStops", "classtvg_1_1Fill.html#addbc9de36b4427639f3cc1dceeccb734", null ],
    [ "colorStops", "classtvg_1_1Fill.html#a92717fc84a7d5df56e42e3bc863fce1a", null ],
    [ "duplicate", "classtvg_1_1Fill.html#a48e358abab4478ff7f84dfb85608eaf3", null ],
    [ "identifier", "classtvg_1_1Fill.html#aee92a597f61d9bbdbd223b5dfc3877b7", null ],
    [ "spread", "classtvg_1_1Fill.html#a55f6de063e5ac8023243c9cef5cb9a12", null ],
    [ "spread", "classtvg_1_1Fill.html#aed49d00ca09e69fdf97aaae235f8e950", null ],
    [ "transform", "classtvg_1_1Fill.html#ad96ad531732975db718aaf1210d47cd7", null ],
    [ "transform", "classtvg_1_1Fill.html#ac9f6ba428afe884bcc2861de0a2a96f4", null ],
    [ "type", "classtvg_1_1Fill.html#aec24b20e43f4edf0fc046517db603181", null ]
];